# Semantic Mapping Reasoning Assembler (SeMRA)

This software provides:

1. An object model for semantic mappings (based on SSSOM)
2. Functionality for assembling and reasoning over
   semantic mappings at scale
3. A provenance model for automatically generated mappings
4. A confidence model granular at the curator-level,
   mapping set-level, and community feedback-level
